/*
sliding.p

AUTHOR : Cyril Kern
MAIL : cyril.kern@free.fr

GAME : SLIDING

AIM : Set each belt around its same color center 

Rules :
- Tap a side to move it to an empty space
- Set all belt around its own center (same color)
- The less move is the best

*/

#include <futurocube>

//face status
new faceValue[6]

new icon[]=[ICON_MAGIC1,ICON_MAGIC2,2,5, 0xFF000000,0xFF000000,0xFF000000,0xFF000000,0x00000000,0xFF000000,0xFF000000, 0xFF000000,0xFF000000,  '''','''']


new const colors[6] = [	cORANGE, 0x00000000, cRED, cBLUE, cGREEN, cMAGENTA ]
new const hole = 1
new nbMove	//the number of face that have been disabled

new const adjacence[6][4] = [
	[2, 3, 4, 5],
	[2, 3, 4, 5],
	[0, 1, 4, 5],
	[0, 1, 4, 5],
	[0, 1, 2, 3],
	[0, 1, 2, 3]
	]
	
main()
{
	ICON(icon)
	RegAllSideTaps() 	//register tap
	initCube()			//init game
	SetIntensity(128)	//set intensity
	new motion			//motion check
	
	draw()
		
	tapToShuffle()
	shuffle()
		
	while( !testWin() ) {

		Sleep()

		motion=Motion()

		//get taped side
		if (motion) 
		{
			tapSide(eTapSide())
			AckMotion()			
		}
		

		//draw the cube
		draw()

	}
	
	//display score
	Score(nbMove, SCORE_NORMAL, 1, 1)


}

/* Wait for tab before shuffling */
tapToShuffle() {
    new motion = 0

    Play("_g_TAPFORSHUFFLE")
    for (;;) {
        Sleep()
        motion=Motion()
        if (motion) {
            AckMotion()
            break
        }
    }

    Delay(100)
}

/* Wait for tab before starting */
tapToStart() {
    new motion = 0

    Play("_g_TAPTOSTART")
    for (;;) {
        Sleep()
        motion=Motion()
        if (motion) {
            AckMotion()
            break
        }
    }

    Delay(100)
}

shuffle() {
	new side = 1
	
	new i
	for (i=0; i<100; i++) {
		new random = GetRnd(4)
		new target = adjacence[side][random]
		new temp = faceValue[target]
		faceValue[target] = faceValue[side]
		faceValue[side] = temp
		side = target
		
		draw()
		Delay(2)
	}
}

//detect the tap on a side
tapSide(side) {

	new i
	new found = false
	new swap = -1
	for (i=0; i<4; i++) {
		if (faceValue[adjacence[side][i]] == hole) {
			swap = adjacence[side][i]
		}
	}
	
	if (swap != -1) {
		new tmp = faceValue[side]
		faceValue[side] = faceValue[swap]
		faceValue[swap] = tmp
		Play("ballhit")
		nbMove = nbMove + 1
	}
	else
	{
		Play("bubble")
	}
	

}

animate(start, end, delay) {
	new i
	for (i=0; i<2; i++) {
		draw()
		
		Delay(delay)
	}
}

//init the cube with default values
initCube() {
	new i
	
	for (i=0; i<6; i++) {
		faceValue[i] = i
	}
}

testWin() {
	new i
	new win=true
	for (i=0; i<6; i++) {
		if (faceValue[i] != i)
			win = false
	}
	return win
}

//draw the cube
draw() {
	new i
	for (i=0; i<6; i++) {
		SetColor(colors[faceValue[i]])
		DrawSide(i)
	}
	
	DrawPC( 4, colors[0])
	DrawPC(13, colors[1])
	DrawPC(22, colors[2])
	DrawPC(31, colors[3])
	DrawPC(40, colors[4])
	DrawPC(49, colors[5])
	
	
	PrintCanvas()
}

